@@ -1,24 +1,27 @@
 """ Loaders Module """
+from __future__ import annotations
+
 import difflib
 import json
 import pathlib
 from json import dumps, loads
-from typing import Callable, Dict, List, Optional, Tuple, cast
-from urllib.parse import ParseResult, urlparse
+from typing import TYPE_CHECKING, cast
+from urllib.parse import urlparse
 
 import yaml
-from django.urls import Resolver404, ResolverMatch, resolve
+from django.urls import Resolver404, resolve
 from django.utils.functional import cached_property
 from openapi_spec_validator import openapi_v2_spec_validator, openapi_v3_spec_validator
-
-# noinspection PyProtectedMember
 from prance.util.resolver import RefResolver
-
-# noinspection PyProtectedMember
 from rest_framework.schemas.generators import BaseSchemaGenerator, EndpointEnumerator
 from rest_framework.settings import api_settings
+from rest_framework.views import APIView
 
-import openapi_tester.type_declarations as td
+if TYPE_CHECKING:
+    from typing import Any, Callable
+    from urllib.parse import ParseResult
+
+    from django.urls import ResolverMatch
 
 
 def handle_recursion_limit(schema: dict) -> Callable:
@@ -47,12 +50,12 @@ class BaseSchemaLoader:
     """
 
     base_path = "/"
-    field_key_map: Dict[str, str]
-    schema: Optional[dict] = None
+    field_key_map: dict[str, str]
+    schema: dict | None = None
 
-    def __init__(self, field_key_map: Optional[Dict[str, str]] = None):
+    def __init__(self, field_key_map: dict[str, str] | None = None):
         super().__init__()
-        self.schema: Optional[dict] = None
+        self.schema: dict | None = None
         self.field_key_map = field_key_map or {}
 
     def load_schema(self) -> dict:
@@ -71,7 +74,7 @@ class BaseSchemaLoader:
         return self.get_schema()
 
     def de_reference_schema(self, schema: dict) -> dict:
-        url = schema["basePath"] if "basePath" in schema else self.base_path
+        url = schema.get("basePath", self.base_path)
         recursion_handler = handle_recursion_limit(schema)
         resolver = RefResolver(
             schema,
@@ -82,8 +85,8 @@ class BaseSchemaLoader:
         resolver.resolve_references()
         return resolver.specs
 
-    def normalize_schema_paths(self, schema: dict) -> Dict[str, dict]:
-        normalized_paths: Dict[str, dict] = {}
+    def normalize_schema_paths(self, schema: dict) -> dict[str, dict]:
+        normalized_paths: dict[str, dict] = {}
         for key, value in schema["paths"].items():
             try:
                 parameterized_path, _ = self.resolve_path(endpoint_path=key, method=list(value.keys())[0])
@@ -109,13 +112,13 @@ class BaseSchemaLoader:
         self.schema = self.normalize_schema_paths(de_referenced_schema)
 
     @cached_property
-    def endpoints(self) -> List[str]:  # pylint: disable=no-self-use
+    def endpoints(self) -> list[str]:  # pylint: disable=no-self-use
         """
         Returns a list of endpoint paths.
         """
         return list({endpoint[0] for endpoint in EndpointEnumerator().get_api_endpoints()})
 
-    def resolve_path(self, endpoint_path: str, method: str) -> Tuple[str, ResolverMatch]:
+    def resolve_path(self, endpoint_path: str, method: str) -> tuple[str, ResolverMatch]:
         """
         Resolves a Django path.
         """
@@ -135,7 +138,7 @@ class BaseSchemaLoader:
                 for key, value in reversed(list(resolved_route.kwargs.items())):
                     index = path.rfind(str(value))
                     path = f"{path[:index]}{{{key}}}{path[index + len(str(value)):]}"
-                if "{pk}" in path and api_settings.SCHEMA_COERCE_PATH_PK:
+                if "{pk}" in path and api_settings.SCHEMA_COERCE_PATH_PK:  # noqa: FS003
                     path, resolved_route = self.handle_pk_parameter(
                         resolved_route=resolved_route, path=path, method=method
                     )
@@ -147,12 +150,12 @@ class BaseSchemaLoader:
         raise ValueError(message)
 
     @staticmethod
-    def handle_pk_parameter(resolved_route: ResolverMatch, path: str, method: str) -> Tuple[str, ResolverMatch]:
+    def handle_pk_parameter(resolved_route: ResolverMatch, path: str, method: str) -> tuple[str, ResolverMatch]:
         """
         Handle the DRF conversion of params called {pk} into a named parameter based on Model field
         """
         coerced_path = BaseSchemaGenerator().coerce_path(
-            path=path, method=method, view=cast(td.APIView, resolved_route.func)
+            path=path, method=method, view=cast(APIView, resolved_route.func)
         )
         pk_field_name = "".join(
             entry.replace("+ ", "") for entry in difflib.Differ().compare(path, coerced_path) if "+ " in entry
@@ -167,7 +170,7 @@ class DrfYasgSchemaLoader(BaseSchemaLoader):
     Loads OpenAPI schema generated by drf_yasg.
     """
 
-    def __init__(self, field_key_map: Optional[Dict[str, str]] = None) -> None:
+    def __init__(self, field_key_map: dict[str, str] | None = None) -> None:
         super().__init__(field_key_map=field_key_map)
         from drf_yasg.generators import OpenAPISchemaGenerator
         from drf_yasg.openapi import Info
@@ -179,9 +182,9 @@ class DrfYasgSchemaLoader(BaseSchemaLoader):
         Loads generated schema from drf-yasg and returns it as a dict.
         """
         odict_schema = self.schema_generator.get_schema(None, True)
-        return loads(dumps(odict_schema.as_odict()))
+        return cast(dict, loads(dumps(odict_schema.as_odict())))
 
-    def resolve_path(self, endpoint_path: str, method: str) -> Tuple[str, ResolverMatch]:
+    def resolve_path(self, endpoint_path: str, method: str) -> tuple[str, ResolverMatch]:
         de_parameterized_path, resolved_path = super().resolve_path(endpoint_path=endpoint_path, method=method)
         path_prefix = self.schema_generator.determine_path_prefix(self.endpoints)
         trim_length = len(path_prefix) if path_prefix != "/" else 0
@@ -193,7 +196,7 @@ class DrfSpectacularSchemaLoader(BaseSchemaLoader):
     Loads OpenAPI schema generated by drf_spectacular.
     """
 
-    def __init__(self, field_key_map: Optional[Dict[str, str]] = None) -> None:
+    def __init__(self, field_key_map: dict[str, str] | None = None) -> None:
         super().__init__(field_key_map=field_key_map)
         from drf_spectacular.generators import SchemaGenerator
 
@@ -203,9 +206,9 @@ class DrfSpectacularSchemaLoader(BaseSchemaLoader):
         """
         Loads generated schema from drf_spectacular and returns it as a dict.
         """
-        return loads(dumps(self.schema_generator.get_schema(public=True)))
+        return cast(dict, loads(dumps(self.schema_generator.get_schema(public=True))))
 
-    def resolve_path(self, endpoint_path: str, method: str) -> Tuple[str, ResolverMatch]:
+    def resolve_path(self, endpoint_path: str, method: str) -> tuple[str, ResolverMatch]:
         from drf_spectacular.settings import spectacular_settings
 
         de_parameterized_path, resolved_path = super().resolve_path(endpoint_path=endpoint_path, method=method)
@@ -220,11 +223,11 @@ class StaticSchemaLoader(BaseSchemaLoader):
     Loads OpenAPI schema from a static file.
     """
 
-    def __init__(self, path: str, field_key_map: Optional[Dict[str, str]] = None):
+    def __init__(self, path: str, field_key_map: dict[str, str] | None = None):
         super().__init__(field_key_map=field_key_map)
         self.path = path if not isinstance(path, pathlib.PosixPath) else str(path)
 
-    def load_schema(self) -> dict:
+    def load_schema(self) -> dict[str, Any]:
         """
         Loads a static OpenAPI schema from file, and parses it to a python dict.
 
@@ -233,4 +236,6 @@ class StaticSchemaLoader(BaseSchemaLoader):
         """
         with open(self.path, encoding="utf-8") as file:
             content = file.read()
-            return json.loads(content) if ".json" in self.path else yaml.load(content, Loader=yaml.FullLoader)
+            return cast(
+                dict, json.loads(content) if ".json" in self.path else yaml.load(content, Loader=yaml.FullLoader)
+            )
